@@ -1,3 +1,8 @@
+//! Information about the tortuga command.
+
+/// The name of the command-line interface executable.
+pub const PROGRAM: &str = env!("CARGO_CRATE_NAME");
+
 /// The full (major, minor, and path) version of Tortuga.
 pub const VERSION: &str = env!("CARGO_PKG_VERSION");
 
